@@ -768,7 +768,7 @@ void FastText::startThreads(std::string pth, int MilliSecs) {
   std::vector<std::thread> threads;
   for (int32_t i = 0; i < args_->thread; i++) {
     // threads.push_back(std::thread([=]() { trainThread(i); }));                   // this gives warning: implicit capture of 'this' via '[=]' is deprecated in C++20 [-Wdeprecated]
-    threads.push_back(std::thread([=, this]() { trainThread(i); }));
+    threads.push_back(std::thread([this, i]() { trainThread(i); }));
   }
   const int64_t ntokens = dict_->ntokens();
 
